@@ -25,7 +25,7 @@ public:
     virtual QString location();
     virtual bool retrieveCvsignoreFile();
 protected:
-    Repository_stub() : DCOPStub( never_use ) {};
+    Repository_stub() : DCOPStub( never_use ) {}
 };
 
 
